@@ -3,11 +3,12 @@ use warnings;
 
 package Perl::PrereqScanner::Scanner::Perl5;
 {
-  $Perl::PrereqScanner::Scanner::Perl5::VERSION = '1.015';
+  $Perl::PrereqScanner::Scanner::Perl5::VERSION = '1.016';
 }
+# ABSTRACT: scan for core Perl 5 language indicators of required modules
+
 use Moose;
 with 'Perl::PrereqScanner::Scanner';
-# ABSTRACT: scan for core Perl 5 language indicators of required modules
 
 
 sub scan_for_prereqs {
@@ -22,11 +23,6 @@ sub scan_for_prereqs {
       next;
     }
 
-    # skip lib.pm
-    # lib.pm is not indexed in 02packages, so listing it as a prereq is not a
-    # good idea. -- rjbs, 2011-08-17
-    next if grep { $_ eq $node->module } qw{ lib };
-
     # inheritance
     if (grep { $_ eq $node->module } qw{ base parent }) {
       # rt#55713: skip arguments to base or parent, focus only on inheritance
@@ -90,7 +86,6 @@ sub _check_required_version {
   return;                       # No minimum version found
 } # end _check_required_version
 
-
 1;
 
 __END__
@@ -103,7 +98,7 @@ Perl::PrereqScanner::Scanner::Perl5 - scan for core Perl 5 language indicators o
 
 =head1 VERSION
 
-version 1.015
+version 1.016
 
 =head1 DESCRIPTION
 
